@@ -675,12 +675,13 @@ class RunConfig:
             if _is_gray_parameter(param):
                 continue
 
+            jset_ids  = jetto_tools.template.Template.extract_jset_ids(self._template.lookup[param])
+            for jset_id in jset_ids:
+                if jset_id is not None:
+                    jset[jset_id] = value
             jset_id = self._template.lookup[param]['jset_id']
-            field = self._template.lookup[param]['nml_id']['field']
-
-            if jset_id is not None:
-                jset[jset_id] = value
-            else:
+            if jset_id is None:
+                field = self._template.lookup[param]['nml_id']['field']
                 if field in jset.extras:
                     extras = jset.extras
                 else:
@@ -731,6 +732,9 @@ class RunConfig:
             if _is_gray_parameter(param):
                 continue
 
+            if 'nml_id' not in self._template.lookup[param]:
+                continue
+
             namelist_id, field = self._template.lookup[param]['nml_id']['namelist'], \
                                  self._template.lookup[param]['nml_id']['field']
             if namelist.exists(namelist_id, field):
@@ -807,7 +811,10 @@ class RunConfig:
             dest_file_path = path.joinpath(src_file_name)
 
             if os.path.isfile(src_file_path):
-                copyfile(src_file_path, dest_file_path)
+                if not os.path.isfile(dest_file_path):
+                    copyfile(src_file_path, dest_file_path)
+                elif not os.path.samefile(src_file_path,dest_file_path):
+                    copyfile(src_file_path, dest_file_path)
             else:
                 raise RunConfigError(f"Cannot find file at '{src_file_path}'")
 
@@ -1228,13 +1235,13 @@ class RunConfig:
         :rtype: int, float, or list
         """
         jset_id = param['jset_id']
-        field = param['nml_id']['field']
         dimension = param['dimension']
         type_ = param['type']
 
         if jset_id is not None:
             value = jset[jset_id]
         else:
+            field = param['nml_id']['field']
             if field in jset.extras:
                 extras = jset.extras
             else:
@@ -1246,11 +1253,10 @@ class RunConfig:
                 value = extras[field].as_list()
             else:
                 raise RunConfigError(f'Extra namelist item {field} not of expected dimension')
-
         return cls._convert_value(value, type_, dimension)
 
     @classmethod
-    def _convert_value(cls, value, destination_type: str, destination_dimension='scalar') -> Union[int, float, List]:
+    def _convert_value(cls, value, destination_type: str, destination_dimension='scalar') -> Union[int, float, List[int], List[float], str]:
         """Convert a value to the destination type
 
         Destination type is one of the values supported by the run configuration i.e. ints or floats, or lists of ints
@@ -1273,6 +1279,8 @@ class RunConfig:
         else:
             if destination_type == 'int':
                 return cls._convert_value_to_int(value)
+            elif destination_type == 'str':
+                return value
             else:
                 return cls._convert_value_to_float(value)
 
